@@ -1,7 +1,9 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+__app_name__  = "a2svm"
 __author__ = "Cyprien Devillez"
 __license__ = "GPL"
-__version__ = "0.0.3"
+__author_email__ = "cyp@bidouille.info"
+__version__ = "0.0.4"
 __description__ = "Simple CLI tool to create and delete easily virtual hosts in Apache."  
\ No newline at end of file
